NodeInfo class final

What a node publishes, subscribes to and serves.

Annotations
  • @immutable

Constructors

NodeInfo({required String name, required List<String> publishing, required List<String> subscribing, required List<String> services})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
final
publishing → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
services → List<String>
final
subscribing → List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited