StringMsg class final

std_msgs/msg/String.

Implemented types
Annotations
  • @immutable

Constructors

StringMsg([String data = ''])
const
StringMsg.fromJson(Map<String, Object?> json)
factory

Properties

data → String
final
hashCode → int
The hash code for this object.
no setteroverride
rosType → String
The fully qualified ROS type name, e.g. geometry_msgs/msg/Twist.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
The rosbridge JSON representation of this message.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override