JointState class final
sensor_msgs/msg/JointState.
- Implemented types
- Annotations
-
- @immutable
Constructors
-
JointState({Header header = const Header(), List<
String> name = const [], required Float64List position, required Float64List velocity, required Float64List effort}) -
const
-
JointState.fromJson(Map<
String, Object?> json) -
factory
Properties
- effort → Float64List
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- header → Header
-
final
-
name
→ List<
String> -
final
- position → Float64List
-
final
- rosType → String
-
The fully qualified ROS type name, e.g.
geometry_msgs/msg/Twist.no setteroverride - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- velocity → Float64List
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
positionOf(
String jointName) → double? -
Position of the joint called
jointName, ornullif absent. -
toJson(
) → Map< String, Object?> -
The rosbridge JSON representation of this message.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override